# Components code style

## Base

* Don't use state in component.
* Use `const` if your variable can not be changed.
* Use arrow functions for all cases.
* Don't ignore eslint errors! If you see error - fix it.
* Use meaningful names for variables, properties and methods.

All static values it is constants, if this reusable variable - add it to config file.
All local constants must be described in top of file and name must be uppercase like `MY_CONST = 100`

#### Examples:

Bad:
```javascript
const t = setTimeout(() => {}, 100);
```

Good:
```javascript
const DEBOUNCE_TIMEOUT = 100;

const timeoutId = setTimeout(() => {}, DEBOUNCE_TIMEOUT);
```

Describe `displayName`, `propTypes` and `defaultProps` use static class props.

Use only one line break between properties/methods

Example:
```javascript

import React from 'react';
import PropTypes from 'prop-types';

import './indsex.scss';

/**
 * ## Usage
 *
 * ```javascript
 * import Example from '@Components/Example';
 *
 * export default class {
 *   render() {
 *     return (
 *       <Example />
 *     );
 *   }
 * }
 * ```
 */
export default class Example extends React.PureComponent {
  static displayName = 'Example';

  static propTypes = {
    /**
     * Property description
     */
    example: PropTypes.bool,
    /**
     * Click handler
     */
    onClick: PropTypes.func,
  };

  static defaultProps = {
    example: false,
    onClick: () => {},
  };

  render() {
    const { example, onClick } = this.props;

    return (
      <section className="example" onClick={onClick} role="presentation">
        <div className="example__text">Example component</div>
        <div className="example__flag">
          example prop: <b>{example.toString()}</b>
        </div>
      </section>
    );
  }
}

```

Example for two dependent components:
```javascript

export class ListItem extends React.Component {
	...
}

export default class List extends React.Component {
	...
}
```

### Styles

We use BEM methodology

#### Class names

* Element - `block__element`
* Block modifier - `block_modifier`
* Element modifier - `block__elem_modifier`
* Modifier with type - `block__elem_modifier-name_modifier-value`

Example:
```scss
.button {
  display: inline-block;
  font-size: 12px;
  border: none;
  
  &_disabled {
    pointer-events: none;
    opacity: 0.5;
  }
  
  &_color_gray {
    background-color: #999999;
  }
  
  &__text {
    display: inline-block;
    text-transform: uppercase;
  }
  
  &__text-icon {
    display: inline-block;
    width: 16px;
    height: 16px;
  }
}
```
