import React from 'react';
import PropTypes from 'prop-types';
import Snackbar from 'material-ui/Snackbar';
import Icon from '../Icon';
import './index.scss';

/**
 * ## Usage
 *
 * ```javascript
 * import AmountFormat from '@Components/Alert';
 *
 * export default class {
 *   render() {
 *     return (
 *       <Alert
 *          open
 *          type={"success"}
 *       >
 *       some text
 *       </Alert>
 *     );
 *   }
 * }
 * ```
 */
export default class Alert extends React.Component {
  static propTypes = {
    open: PropTypes.bool, // eslint-disable-line
    type: PropTypes.oneOf(['success', 'error', 'warning', false]),
    children: PropTypes.any,// eslint-disable-line
  };

  static IconSize = 16;

  static defaultProps = {
    type: false
  };

  get icon() {
    switch (this.props.type) {
      case 'success':
        return (<Icon name="check-round" color="green" size={24} />);
      case 'error':
        return (<Icon name="error" color="red" size={28} />);
      case 'warning':
        return (<Icon name="warning" color="#FFC107" size={24} />);
      default:
        return null;
    }
  }

  render() {
    const { children, onClose, onExit, open, timeout } = this.props;

    return (
      <Snackbar
        classes={{ root: 'alert__wrapper-root' }}
        anchorOrigin={{ vertical: 'top', horizontal: 'left' }}
        open={open}
        autoHideDuration={timeout}
        onClose={onClose}
        SnackbarContentProps={{ 'aria-describedby': 'message-id', classes: { root: 'alert__root' } }}
        message={
          (
            <div className="alert__body" >
              <span className="alert__icon" >
                {this.icon}
              </span>
              <p className="alert__message" >
                {children}
              </p>
            </div>
          )
        }
        onExited={onExit}
        action={[
          <button key="button" className="alert__close-btn" onClick={onClose} >
            <Icon name="close" color="rgba(0,0,0,0.87)" size={Alert.IconSize} />
          </button>,
        ]}
      />
    );
  }
}
