import React from 'react';
import PropTypes from 'prop-types';

import './index.scss';

const decomposeAmount = amount => (parseFloat(amount))
  .toLocaleString('ru-RU', { maximumFractionDigits: 2, minimumFractionDigits: 2 })
  .toString()
  .split(',');

/**
 * ## Usage
 *
 * ```javascript
 * import AmountFormat from '@Components/AmountFormat';
 *
 * export default class {
 *   render() {
 *     return (
 *       <AmountFormat
 *         amount={10.12}
 *         prefix={'$ '}
 *         theme="default" // by default, or you can use customTheme="your-custom-theme"
 *       />
 *     );
 *   }
 * }
 * ```
 */
export default class AmountFormat extends React.PureComponent {
  static displayName = 'AmountFormat';

  static propTypes = {
    amount: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.number,
    ]).isRequired,
    prefix: PropTypes.string,
    suffix: PropTypes.string,
    customTheme: PropTypes.string,
    theme: PropTypes.oneOf([
      'default',
      'bold',
      'account-selector',
      'statement-account-info',
      'account-card-last-move',
      'account-card-credit-limit',
      'account-card-balance',
      'payment-view-banner-amount',
      'payment-view-banner-amount-blue',
      'statement-table-amount',
      'statement-table-amount_blue',
      'default-table-amount',
    ]),
  };

  static defaultProps = {
    prefix: '',
    suffix: '',
    theme: 'default',
    customTheme: '',
  };

  render() {
    const {
      customTheme, theme, prefix, suffix, amount,
    } = this.props;

    const [wholePart, fraction] = decomposeAmount(amount);
    return amount ? (
      <span className={`amount-format amount-format_theme_${customTheme || theme}`}>
        <span className="amount-format__prefix">{prefix}</span>
        {' '}
        <span className="amount-format__whole-part">{wholePart}</span>
        {'.'}
        <span className="amount-format__fraction">{fraction}</span>
        {' '}
        <span className="amount-format__suffix">{suffix}</span>
      </span>
    ) : (
      <span className={`amount-format amount-format_theme_${customTheme || theme}`}>
        <span className="amount-format__prefix">{prefix}</span>
        <span className="amount-format__empty"> — — . — — </span>
        <span className="amount-format__suffix">{suffix}</span>
      </span>
    );
  }
}

