import React from 'react';
import PropTypes from 'prop-types';
import CustomInput from 'react-nebo15-currency-input';

import TextInput from '../TextInput';

/**
 * ## Usage
 *
 * ```javascript
 * import { Field } from 'redux-form/immutable';
 * import AmountInput from '@Components/AmountInput';
 *
 * export default class {
 *   render() {
 *     return (
 *       <Field
 *          name="amount"
 *          component={AmountInput}
 *          label="Amount"
 *          precision={2}
 *       />
 *     );
 *   }
 * }
 * ```
 */
export default class AmountInput extends React.Component {
  static displayName = 'AmountInput';

  static propTypes = {
    ...TextInput.propTypes,
    label: PropTypes.string,
    disabled: PropTypes.bool,
    prefix: PropTypes.string,
    suffix: PropTypes.string,
    input: PropTypes.object,
    autoFocus: PropTypes.bool,
    decimalSeparator: PropTypes.string,
    precision: PropTypes.number,
    maxLength: PropTypes.number,
    defaultPrecision: PropTypes.bool,
    theme: PropTypes.oneOf([
      'default',
      'payments-form',
      'payments-form-amount',
    ])
  };

  static defaultProps = {
    ...TextInput.defaultProps,
    decimalSeparator: '.',
    precision: 0,
    maxLength: 10,
    defaultPrecision: false,
  };

  render() {
    const {
      decimalSeparator, precision, maxLength, defaultPrecision
    } = this.props;

    return (
      <TextInput
        {...this.props}
        inputComponent={CustomInput}
        inputProps={{
          decimalSeparator,
          precision,
          maxLength,
          onBlur: (e) => {
            if (!defaultPrecision || e.target.value.length === 0) {
              return;
            }

            e.stopPropagation();

            const amount = e.target.value.split(decimalSeparator);

            if (amount.length === 1) {
              amount[1] = new Array(precision + 1).join('0');
            } else if (amount[1].length === 1) {
              amount[1] += new Array(precision).join('0');
            }

            e.target.value = `${amount[0]}${decimalSeparator}${amount[1]}`;

            this.props.input.onBlur(e);
          }
        }}
      />
    );
  }
}
