import React from 'react';
import PropTypes from 'prop-types';

import {
  FormControl,
  FormControlLabel,
  FormHelperText,
} from 'material-ui/Form';
import CheckboxUI from 'material-ui/Checkbox';

import './index.scss';

/**
 * ## Usage
 *
 * ```javascript
 * import { Field } from 'redux-form/immutable';
 * import Checkbox from '@Components/Checkbox';
 *
 * export default class {
 *   render() {
 *     return (
 *       <Field
 *          name="myCheckbox"
 *          component={Checkbox}
 *          label="Label text"
 *       />
 *     );
 *   }
 * }
 * ```
 */
export default class Checkbox extends React.Component {
  static displayName = 'Checkbox';

  static propTypes = {
    label: PropTypes.string,
    id: PropTypes.string,
    disabled: PropTypes.bool,
    helperText: PropTypes.string,
    input: PropTypes.object,
    meta: PropTypes.object,
  };

  static defaultProps = {
    label: undefined,
    helperText: undefined,
    id: undefined,
    input: {},
    meta: {},
    disabled: false,
  };

  render() {
    const {
      label, helperText, input, id, disabled, meta,
    } = this.props;

    const error = (
      meta.touched || (meta.visited && !meta.active) || meta.submitFailed
    ) && meta.error;

    return (
      <FormControl disabled={disabled} className="checkbox">
        <FormControlLabel
          control={
            <CheckboxUI
              {...input}
              classes={{
                checked: 'checkbox__input_checked',
              }}
              id={id}
              icon={(<div className="checkbox__border" />)}
            />
          }
          label={
            <div>
              {label}
            </div>
          }
        />
        {helperText && <div className="checkbox__help-text">{helperText}</div>}
        {error && <FormHelperText className="checkbox__help-text_error">{error}</FormHelperText>}
      </FormControl>
    );
  }
}
