import React from 'react';
import PropTypes from 'prop-types';
import { CircularProgress as CircularProgressUI } from 'material-ui/Progress';
import './index.scss';

const THICKNESSES = {
  thick: 2,
  normal: 3.5,
  bold: 5,
};

const SIZES = {
  nano: 30,
  small: 50,
  medium: 100,
  large: 150,
};

/**
 * ## Usage
 *
 * ```javascript
 * import CircularProgress from '@Components/CircularProgress';
 *
 * export default class {
 *   render() {
 *     return (
 *       <CircularProgress isPreload>
 *           <div>{'Hola!'}</div>
 *       </CircularProgress>
 *     );
 *   }
 * }
 * ```
 */
export default class CircularProgress extends React.PureComponent {
  static displayName = 'CircularProgress';

  static propTypes = {
    /** Will be display when isPreload - false */
    children: PropTypes.any,
    isPreload: PropTypes.bool,
    thickness: PropTypes.oneOf(['thick', 'normal', 'bold']),
    size: PropTypes.oneOf(['nano', 'small', 'medium', 'large']),
  };

  static defaultProps = {
    children: '',
    isPreload: false,
    thickness: 'normal',
    size: 'medium',
  };

  render() {
    const {
      isPreload, children, thickness, size,
    } = this.props;

    if (isPreload) {
      return (
        <section className="tas-circular-progress">
          <CircularProgressUI
            thickness={THICKNESSES[thickness]}
            size={SIZES[size]}
          />
        </section>
      );
    }

    return children;
  }
}

