import React from 'react';
import PropTypes from 'prop-types';
import bemDecorator from 'cn-decorator';

import './index.scss';

/**
 * ## Usage
 *
 * ```javascript
 * import { Field } from 'redux-form/immutable';
 * import TextInput from '@Components/TextInput';
 *
 * export default class {
 *   render() {
 *     return (
 *       <Field
 *          name="myInput"
 *          component={TextInput}
 *          label="Label text"
 *       />
 *     );
 *   }
 * }
 * ```
 */
@bemDecorator('editable-input')
export default class EditableInput extends React.Component {
  static displayName = 'EditableInput';

  static propTypes = {
    theme: PropTypes.oneOf([
      'default',
      'payments-form',
      'payments-form-numbers',
      'autofill-form',
    ]),
  };

  static defaultProps = {
    theme: 'default',
  };

  state = {
    query: '',
    match: {},
  };

  componentDidMount() {
    const { pattern, patternComponents, autofillValues = {}, handleApply } = this.props;
    const match = {};

    pattern.forEach(item => {
      if (autofillValues[item]) {
        match[item] = autofillValues[item];
      }
    })

    const query = pattern.map(word => match[word] ? match[word] : word);

    this.setState({ match });

    handleApply(query);
  }

  handleChange({ name, value }) {
    const { pattern, handleApply } = this.props;
    const { match } = this.state;
    const updatedMatch = { ...match, [name]: value };

    const query = pattern.map(word => updatedMatch[word] ? updatedMatch[word] : word);

    this.setState({
      match: updatedMatch,
      query
    });

    handleApply(query);
  }

  render(bem) {
    const { pattern, patternComponents, autofillValues } = this.props;

    return (
      <section className={bem({ theme: this.props.theme })}>
        {
          pattern.map(item => {
            return (patternComponents[item] && patternComponents[item].component)
              ? patternComponents[item].component({
                ...this.props,
                defaultValue: autofillValues[item],
                handleChange: this.handleChange.bind(this)
              })
              : [<span className={bem('text')}>{item}</span>, <span className={bem('space')}></span>]
          })
        }
      </section>
    );
  }
}
