import React from 'react';
import { createComponentStory } from 'stories';

import EditableInput from './index';
import CustomSelect from '../CustomSelect';
import TextInput from '../TextInput';
import CustomDatePicker from '../CustomDatePicker';

const story = createComponentStory({ component: EditableInput });

story.addWithDoc('EditableInput', ({ props }) => (
  <EditableInput
    pattern={'Name: {{name}}; Age: {{age}}; Date: {{date}};'.split(/{{(.*?)}}/)}
    patternComponents={{
      name: {
        component: ({ handleChange, defaultValue }) => (
          <TextInput
            theme='autofill-form'
            input={{ name: 'name' }}
            inputProps={{
              defaultValue,
              onChange: e => handleChange(e.target)
            }}
          />
        ),
        label: '1'
      },
      age: {
        component: ({ handleChange, defaultValue }) => (
          <CustomSelect
            theme='autofill-form'
            input={{ name: 'age' }}
            onChange={handleChange}
            list={[0, 1, 2, 3]}
            defaultValue={defaultValue}
            defaultCustomValue=''
            customLabel='Власний варіант'
          />
        ),
        label: '2'
      },
      date: {
        component: ({ handleChange, defaultValue }) => (
          <CustomDatePicker
            range={{ startDate: '20.06.2018', endDate: '20.06.2018' }}
            customLabel={defaultValue}
            filter={['month', 'prevMonth', 'quarter', 'prevQuarter']}
            singleDatePicker={true}
            handleApply={range => handleChange({ name: 'date', value: range.labelDate })}
          />
        ),
        label: '3'
      },
    }}
    handleApply={(value) => {
      console.log('apply', value);
    }}
    autofillValues={{
      name: '123',
      age: '321',
      date: '121212'
    }}
    {...props}
  />
));