import React from 'react';
import PropTypes from 'prop-types';

import './index.scss';

/**
 * ## Usage
 *
 * ```javascript
 * import Example from '@Components/Example';
 *
 * export default class {
 *   render() {
 *     return (
 *       <Example />
 *     );
 *   }
 * }
 * ```
 */
export default class Example extends React.PureComponent {
  static displayName = 'Example';

  static propTypes = {
    /**
     * Property description
     */
    example: PropTypes.bool,
    /**
     * Click handler
     */
    onClick: PropTypes.func,
  };

  static defaultProps = {
    example: false,
    onClick: () => {},
  };

  render() {
    const { example, onClick } = this.props;

    return (
      <section className="example" onClick={onClick} role="presentation">
        <div className="example__text">Example component</div>
        <div className="example__flag">
          example prop: <b>{example.toString()}</b>
        </div>
      </section>
    );
  }
}
