import React from 'react';
import PropTypes from 'prop-types';

import UIButton from 'material-ui/Button';
import ADD from './images/ic_add_white.svg';
import EXPORT from './images/ic_export.svg';
import IMPORT from './images/ic_import.svg';
import PRINT from './images/ic_print.svg';
import EYE_OUTLINE from './images/ic_eye_outline.svg';
import EYE_OUTLINE_OFF from './images/ic_eye_outline_off.svg';
import FAVORITE from './images/ic_favorite.svg';

import './index.scss';

const IMAGES = {
  add: ADD,
  export: EXPORT,
  import: IMPORT,
  print: PRINT,
  eye_outline: EYE_OUTLINE,
  eye_outline_off: EYE_OUTLINE_OFF,
  favorite: FAVORITE,
};

/**
 * ## Usage
 *
 * ```javascript
 *
 * DEPRECATED. Use <Button theme="round" />
 *
 * import Button from '@Components/Button';
 *
 * export default class {
 *   render() {
 *     return (
 *       <FabButton
 *          className="your-custom-class"
 *          disabled={false}
 *          theme="your-custom-theme"
 *       />
 *     );
 *   }
 * }
 * ```
 */
export default class FabButton extends React.PureComponent {
  static displayName = 'FabButton';

  static propTypes = {
    children: PropTypes.oneOfType([PropTypes.node, null]),
    disabled: PropTypes.bool,
    disableRipple: PropTypes.bool,
    onClick: PropTypes.func,
    bgColor: PropTypes.oneOf(['white', 'primary']),
    iconType: PropTypes.oneOf(['add', 'export', 'import', 'print', 'eye_outline', 'eye_outline_off', 'favorite']),
    theme: PropTypes.string,
    className: PropTypes.string,
    type: PropTypes.oneOf(['button', 'submit']),
  };

  static defaultProps = {
    theme: 'default',
    type: 'button',
    bgColor: 'white',
    className: '',
    disabled: false,
    disableRipple: true,
    iconType: 'print',
    children: null,
    onClick: () => {},
  };

  render() {
    const {
      children, disabled, onClick, className, theme, type, iconType, bgColor, disableRipple,
    } = this.props;

    return (
      <UIButton
        variant="fab"
        classes={{
          root: `${className} button-fab button-fab_theme-${theme} button-fab_bgColor-${bgColor}`,
          disabled: `button-fab_disabled-${bgColor}`,
        }}
        type={type}
        disableRipple={disableRipple}
        disabled={disabled}
        onClick={onClick}
      >
        { children || <img className="button-fab__default-img" src={IMAGES[iconType]} alt={iconType} />}
      </UIButton>
    );
  }
}
