import React from 'react';
import { createComponentStory } from 'stories';

import GooglePlaceSuggestion, { cityFormatter, getAddress } from './index';
import TextInput from '../TextInput';
import Title from '../Title';
import Alert from '../Alert';

const story = createComponentStory({ component: GooglePlaceSuggestion });

class GooglePlaceSuggestionStory extends React.Component {
  state = {
    city: {
      value: '',
      focused: false,
    },
    street: {
      value: '',
      focused: false,
    },
    isSubmitted: false,
  };

  updateField(name, data) {
    this.setState({ [name]: { ...this.state[name], ...data } });
  }


  render() {
    const { ...otherProps } = this.props;
    const { isSubmitted } = this.state;
    return (
      <div>
        <Title heading={3}>City & street example</Title>
        <GooglePlaceSuggestion
          {...otherProps}
          autocompletionRequest={{
            componentRestrictions: { country: 'ua' },
            types: ['(cities)'],
          }}
          search={this.state.city.focused ? this.state.city.value : ''}
          onSelectSuggest={suggest => this.updateField('city', { value: suggest })}
          textNoResults={null}
          suggestionFormatter={cityFormatter}
        >
          <TextInput
            label="Your mother's city"
            input={{
              value: this.state.city.value,
              onChange: e => this.updateField('city', { value: e.target.value }),
              onFocus: () => this.updateField('city', { focused: true }),
              onBlur: () => this.updateField('city', { focused: false }),
            }}
          />
        </GooglePlaceSuggestion>
        <GooglePlaceSuggestion
          {...otherProps}
          autocompletionRequest={{
            componentRestrictions: { country: 'ua' },
            types: ['address']
          }}
          search={this.state.street.focused && this.state.city.value ? `${this.state.city.value}, ${this.state.street.value}` : ''}
          onSelectSuggest={suggest => this.updateField('street', { value: suggest })}
          textNoResults={null}
          suggestionFormatter={getAddress}
        >
          <TextInput
            label="You mother's street"
            input={{
              value: this.state.street.value,
              onChange: e => this.updateField('street', { value: e.target.value }),
              onFocus: () => this.updateField('street', { focused: true }),
              onBlur: () => this.updateField('street', { focused: false }),
            }}
          />
        </GooglePlaceSuggestion>
        <button onClick={() => this.setState({ isSubmitted: true })} style={{ margin: '20px 0', padding: '5px 20px' }}>Send to @bogdaniy</button>
        <Alert open={isSubmitted} type="success">
          Request was queued.
        </Alert>
        <Title heading={6}>GooglePlaceSuggestion works properly only with redux-form</Title>
      </div>
    );
  }
}

story.addWithDoc(
  'GooglePlaceSuggestion', ({ props }) => <GooglePlaceSuggestionStory {...props} />,
  GooglePlaceSuggestion, {}
);
