import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import styles from './icons.font';

export const ICONS = [
  'add',
  'accounts',
  'acquiring',
  'arrow-down',
  'attach-file',
  'briefcase',
  'calendar',
  'check-double',
  'check-round',
  'close',
  'confirm-email',
  'confirm-phone',
  'content-copy',
  'deposits',
  'dev-tools',
  'done',
  'download',
  'dustbin',
  'divide',
  'edit',
  'error',
  'export',
  'export-file',
  'eye',
  'eye-close',
  'face-sad',
  'facebook',
  'favorite',
  'marketplace',
  'menu',
  'payments',
  'print',
  'heart',
  'repeat',
  'return',
  'search',
  'sign',
  'sign-add',
  'sign-crossed',
  'sign-delete',
  'view-headline',
  'view-module',
  'warning',
  'star',
  'trash',
  'money-back',
  'credit-card',
  'invoice',
  'mobile-phone',
  'online-payment',
  'price-tag',
  'big-five',
  'identification',
  'my-card',
  'check',
  'documents',
  'exit',
  'uah',
  'upload',
  'eur',
  'usd',
  'mail-unread',
  'mail',
];

/**
 * ## Usage
 *
 * ```javascript
 * import Icon from '@components/Icon';
 *
 * export default class {
 *   render() {
 *     return (
 *       <Icon name="my-icon" />
 *     );
 *   }
 * }
 * ```
 */
const Icon = ({
  name, size, color, fill, round, rotate
}) => (
  <i
    style={{
      color,
      fontSize: size,
      backgroundColor: fill,
      transform: `rotate(${rotate}deg)`
    }}
    className={classnames(styles.icon, styles[`icon__${name}`], round && styles.icon_round)}
  />
);

Icon.displayName = 'Icon';

Icon.propTypes = {
  /**
   * Icon name
   */
  name: PropTypes.oneOf(ICONS).isRequired,

  /**
   * Icon size
   */
  size: PropTypes.number,

  /**
   * Icon color
   */
  color: PropTypes.string,

  /**
   * Icon background
   */
  fill: PropTypes.string,

  /**
   * Set border-radius: 50%
   */
  round: PropTypes.bool,

  /**
   * Icon rotate
   */
  rotate: PropTypes.string,

};

Icon.defaultProps = {
  size: 20,
  color: 'inherit',
  fill: 'transparent',
  round: false,
  rotate: '0'
};

export default Icon;
