import React from 'react';
import PropTypes from 'prop-types';
import bemDecorator from 'cn-decorator';

import Button from '../Button';
import Title from '../Title';

import Modal from './index';

/**
 * ## Usage
 *
 * ```javascript
 * import Alert from '@Components/Modal/Alert';
 *
 * export default class {
 *   render() {
 *      return (
 *        <Alert
 *          title="Title text..."
 *          text="Some content..."
 *          confirmLabel="Agree"
 *          onConfirm={...}
 *        />
 *      );
 *   }
 * }
 * ```
 */
@bemDecorator('tas-modal')
export default class AlertModal extends React.Component {
  static displayName = 'AlertModal';

  static propTypes = {
    name: PropTypes.string.isRequired,
    title: PropTypes.string,
    text: PropTypes.string,
    confirmLabel: PropTypes.string,
    onConfirm: PropTypes.func,
  };

  static defaultProps = {
    title: 'Alert',
    text: '',
    confirmLabel: 'Confirm',
    onConfirm() { },
  };

  render(bem) {
    const {
      onConfirm, title, text, confirmLabel, name,
    } = this.props;

    return (
      <Modal
        name={name}
        ref={(ref) => { this.$modal = ref && ref.getWrappedInstance(); }}
        header={(
          <Title heading={4} theme="custom">{title}</Title>
        )}
        footer={(
          <div className={bem('alert-footer')}>
            <Button
              theme="button-link"
              onClick={(e) => {
                this.$modal.hide();
                onConfirm(e);
              }}
            >
              {confirmLabel}
            </Button>
          </div>
        )}
        onClose={onConfirm}
      >
        <span className={bem('alert-text')}>{text}</span>
      </Modal>
    );
  }
}
