import React from 'react';
import { createStore, combineReducers } from 'redux';
import { createComponentStory } from 'stories';
import { action } from '@storybook/addon-actions';

import Button from '../Button';

import Modal from './index';
import Alert from './Alert';
import Confirm from './Confirm';

import modalReducer, { showModal } from './redux';

const store = createStore(combineReducers({
  modal: modalReducer
}));

store.dispatch(showModal('example-modal'));
store.dispatch(showModal('example-alert'));
store.dispatch(showModal('example-confirm'));

const story = createComponentStory({ component: Modal, store });

story.addWithDoc('Default modal', ({ props }) => (
  <div>
    <Button
      onClick={() => store.dispatch(showModal('example-modal'))}
    >
      Show modal
    </Button>
    <Modal
      {...props}
      onClose={action('onClose')}
    />
  </div>
), Modal, {
  defaultProps: {
    name: 'example-modal',
    header: 'Header',
    footer: 'Footer',
    children: 'Content'
  }
});

const storyAlert = createComponentStory({
  component: Modal,
  path: 'Modal/Alert',
  store,
});

storyAlert.addWithDoc('Alert', ({ props }) => (
  <div>
    <Button
      onClick={() => store.dispatch(showModal('example-alert'))}
    >
      Show alert
    </Button>
    <Alert
      {...props}
      onConfirm={action('onConfirm')}
    />
  </div>
), Alert, {
  defaultProps: {
    name: 'example-alert',
    title: 'Alert example',
    text: 'Alert text'
  }
});

const storyConfirm = createComponentStory({
  component: Modal,
  path: 'Modal/Confirm',
  store,
});

storyConfirm.addWithDoc('Confirm', ({ props }) => (
  <div>
    <Button
      onClick={() => store.dispatch(showModal('example-confirm'))}
    >
      Show confirm
    </Button>
    <Confirm
      {...props}
      name="example-confirm"
      onConfirm={action('onConfirm')}
      onCancel={action('onCancel')}
    />
  </div>
), Confirm, {
  defaultProps: {
    name: 'example-confirm',
    title: 'Confirm',
    text: 'Confirm text'
  }
});
