import React from 'react';
import { createStore, combineReducers, applyMiddleware } from 'redux';
import { createComponentStory } from 'stories';
import { action } from '@storybook/addon-actions';

import Button from '../Button';

import Notifications from './index';

import notificationsReducer, { notificationsMiddleware, showNotification, NotificationError } from './redux';

const store = createStore(
  combineReducers({ notifications: notificationsReducer }),
  applyMiddleware(notificationsMiddleware)
);

const story = createComponentStory({ component: Notifications, store });

store.dispatch(showNotification({
  type: 'success',
  title: 'Success',
  message: 'Notification message success'
}));

store.dispatch(showNotification({
  type: 'warning',
  title: 'Warning',
  message: 'Notification message warning'
}));

store.dispatch(showNotification({
  type: 'error',
  title: 'Error',
  message: 'Notification message error'
}));

story.addWithDoc('Default', () => (
  <div>
    <p>
      <Button
        onClick={() => {
          store.dispatch(showNotification({
            type: 'success',
            title: 'New notification',
            message: 'Notification message success'
          }));
        }}
      >
        Add notification
      </Button>
    </p>
    <br />
    <p>
      <Button
        onClick={() => {
          throw new NotificationError({
            title: 'Throw error',
            message: 'Throw error message'
          });
        }}
      >
        Throw notification error
      </Button>
    </p>

    <Notifications />
  </div>
), Notifications);
