const SHOW_NOTIFICATION = '@notifications/SHOW';
const HIDE_NOTIFICATION = '@notifications/HIDE';
const DELETE_NOTIFICATION = '@notifications/DELETE';
const HIDE_ALL_NOTIFICATIONS = '@notifications/HIDE_ALL';

const store = { dispatch: () => { }, getState: () => ({ }) };

export const showNotification = ({ type, title, message, meta = {} }) => ({
  type: SHOW_NOTIFICATION,
  payload: {
    type, title, message, meta,
  }
});

export const hideNotification = (index = 0) => ({
  type: HIDE_NOTIFICATION,
  payload: {
    index
  },
});

export const deleteNotification = (index = 0) => ({
  type: DELETE_NOTIFICATION,
  payload: {
    index
  },
});

export const hideAllNotifications = () => ({
  type: HIDE_ALL_NOTIFICATIONS,
  payload: null,
});

export const notificationsMiddleware = ({ dispatch, getState }) => {
  store.dispatch = dispatch;
  store.getState = getState;

  return next => action => next(action);
};

export class NotificationError extends Error {
  constructor({ title, message, meta }) {
    super(`${title} - ${message}`);

    store.dispatch(showNotification({
      type: 'error',
      title,
      message,
      meta,
    }));
  }
}

export default (state = [], action) => {
  switch (action.type) {
    case SHOW_NOTIFICATION:
      return [
        ...state,
        { ...action.payload, open: true }
      ];
    case HIDE_NOTIFICATION:
      const newState = [...state];

      newState[action.payload.index] = {
        ...state[action.payload.index],
        open: false,
      };

      return newState;
    case DELETE_NOTIFICATION:
      state.splice(action.payload.index, 1);
      return [...state];
    case HIDE_ALL_NOTIFICATIONS:
      return [...state].map(item => ({ ...item, open: false }));
    default:
      return state;
  }
};
