import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

import './index.scss';


/**
 * ## About Component
 * ## Usage
 *
 * ```javascript
 * import Paper from '@Components/Paper';
 *
 * export default class {
 *   render() {
 *     return (
 *       <Paper>
 *           <div>Hola!</div>
 *       </Paper>
 *     );
 *   }
 * }
 * ```
 */
export default class Paper extends React.PureComponent {
  static displayName = 'Paper';

  static propTypes = {
    shadowType: PropTypes.oneOf(['default', 'light']),
    theme: PropTypes.oneOf([false, 'no-radius', 'top-border-blue']),
  };

  static defaultProps = {
    shadowType: 'default',
    theme: false,
  };

  render() {
    const { theme, shadowType, children } = this.props;
    return (
      <div className={classNames('paper', {
        [`paper__theme-${theme}`]: theme,
        [`paper_shadow_${shadowType}`]: shadowType
      })}
      >{children}
      </div>
    );
  }
}
