import React from 'react';
import PropTypes from 'prop-types';

import Radio from 'material-ui/Radio';
import { FormControl, FormControlLabel, FormHelperText } from 'material-ui/Form';

import './index.scss';

/**
 * ## Usage
 *
 * ```javascript
 * import { Field } from 'redux-form/immutable';
 * import RadioInput from '@Components/RadioInput';
 *
 * export default class {
 *   render() {
 *     return (
 *       <Field
 *          name="myRadioInput"
 *          component={RadioInput}
 *          label="Label text"
 *       />
 *     );
 *   }
 * }
 * ```
 */
export default class RadioInput extends React.Component {
  static displayName = 'RadioInput';

  static propTypes = {
    label: PropTypes.string,
    id: PropTypes.string,
    disabled: PropTypes.bool,
    checked: PropTypes.bool,
    helperText: PropTypes.string,
    input: PropTypes.object,
    meta: PropTypes.object,
  };

  static defaultProps = {
    label: undefined,
    helperText: undefined,
    id: undefined,
    input: {},
    meta: {},
    disabled: false,
    checked: false,
  };

  render() {
    const {
      label, helperText, input, id, disabled, meta, checked,
    } = this.props;

    const error = (
      meta.touched || (meta.visited && !meta.active) || meta.submitFailed
    ) && meta.error;

    return (
      <FormControl error={error} disabled={disabled} className="radio-input">
        <FormControlLabel
          {...input}
          control={
            <Radio
              id={id}
              classes={{
                default: 'radio-input__input',
                checked: 'radio-input__input_checked',
                disabled: 'radio-input__input_disabled',
              }}
              checked={input.checked || checked}
              {...input}
            />
          }
          label={
            <div>
              {label}
              <div className="radio-input__help-text">{helperText}</div>
            </div>
          }
        />
        {error && <FormHelperText className="radio-input__help-text_error">{error}</FormHelperText>}
      </FormControl>
    );
  }
}
