import React from 'react';
import PropTypes from 'prop-types';
import bemDecorator from 'cn-decorator';

import './index.scss';

/**
 * ## Usage
 *
 * ```javascript
 * import Switch from '@Components/Switch';
 *
 * export default class {
 *   render() {
 *     return (
 *       <Field
 *          name="your-field-name"
 *          id="your-field-id"
 *          label="your-field-label"
 *          component={Switch}
 *       />
 *     );
 *   }
 * }
 * ```
 */
@bemDecorator('switch')
export default class Switch extends React.PureComponent {
  static displayName = 'Switch';

  static propTypes = {
    id: PropTypes.string,
    label: PropTypes.string,
    disable: PropTypes.bool,
  };

  static defaultProps = {
    id: undefined,
    label: undefined,
    disable: false,
  };

  render(bem) {
    const { input, id, label, disable } = this.props;

    return (
      <div className={bem({ checked: input.value, disable })}>
        <input
          type="checkbox"
          id={id}
          className={bem('input')}
          {...input}
          onChange={() => { input.onChange(!input.value); }}
          onBlur={() => { input.onBlur(input.value); }}
        />

        <div className={bem('background')} />

        <button className={bem('button')} />

        <label htmlFor={id} className={bem('label')}>{label}</label>
      </div>
    );
  }
}
