import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import {
  TableCell,
  TableHead,
  TableRow,
  TableSortLabel,
} from 'material-ui/Table';
import Checkbox from '../../Checkbox';

export default class Head extends React.Component {
  static displayName = 'Head';

  static propTypes = {
    numSelected: PropTypes.number.isRequired,
    onRequestSort: PropTypes.func.isRequired,
    onSelectAllClick: PropTypes.func.isRequired,
    order: PropTypes.string.isRequired,
    orderBy: PropTypes.string.isRequired,
    rowCount: PropTypes.number.isRequired,
    withCheckboxes: PropTypes.bool.isRequired,
  };

  getTableCellClassName(key) {
    const index = this.props.columnData.findIndex(i => i.id === key);
    return classNames('tas-table__cell', {
      'tas-table__cell_first': index === 0,
      'tas-table__cell_last': index === this.props.columnData.length - 1,
    });
  }

  render() {
    const {
      onRequestSort, onSelectAllClick, order, orderBy, withSort,
      numSelected, rowCount, columnData, withCheckboxes,
    } = this.props;

    return (
      <TableHead className="tas-table__head">
        <TableRow className="tas-table__row tas-table__row_head">
          {withCheckboxes && (
            <TableCell
              className="tas-table__cell tas-table__cell_checkbox"
              padding="none"
            >
              <Checkbox
                input={{
                  checked: rowCount && numSelected === rowCount,
                  indeterminate: numSelected > 0 && numSelected < rowCount,
                  onChange: (e, all) => onSelectAllClick(e, all),
                }}
              />
            </TableCell>
          )}

          {columnData.map(column => (
            <TableCell
              className={this.getTableCellClassName(column.id)}
              padding="none"
              key={column.id}
              numeric={column.alignRight}
              sortDirection={orderBy === column.id ? order : false}
              style={{ width: column.width }}
            >
              {withSort && column.orderBy ? (
                <TableSortLabel
                  active={orderBy === column.id || orderBy === column.orderBy}
                  direction={order}
                  onClick={event => onRequestSort({ event, column })}
                >{column.label}
                </TableSortLabel>
              ) : column.label}
            </TableCell>
          ))}
        </TableRow>
      </TableHead>
    );
  }
}
