import React from 'react';
import PropTypes from 'prop-types';
import className from 'classnames';
import TextInput from '../../TextInput';

export default class ToolBar extends React.Component {
  static displayName = 'ToolBar';

  static propTypes = {
    labelChosen: PropTypes.string.isRequired,
    selectedCount: PropTypes.number.isRequired,
    mainLabel: PropTypes.string.isRequired,
    onChangeSearchValue: PropTypes.func.isRequired,
    tools: PropTypes.any.isRequired,
    innerRef: PropTypes.func.isRequired,
  };

  state = {
    searchValue: '',
    visible: false,
    focused: false,
  };

  get toolBarLabelClassName() {
    return className('tas-table__tool-bar-label', {
      'tas-table__tool-bar-label_active': this.state.visible,
      'tas-table__tool-bar-label_focused': this.state.focused,
      'tas-table__tool-bar-label_empty': !this.props.withSearchBar && !this.props.mainLabel,
    });
  }

  handleClick() {
    this.searchInput.focus();
    this.setState({
      visible: true,
      focused: true,
    });
  }

  handleBlur() {
    this.setState({ focused: false });
    if (!this.state.searchValue) {
      this.setState({ visible: false });
    }
  }

  handleChangeSearchValue({ target: { value } }) {
    this.setState({ searchValue: value });
    this.props.onChangeSearchValue(value);
  }

  render() {
    const {
      selectedCount, mainLabel, labelChosen, withSearchBar, tools, innerRef,
    } = this.props;

    return (
      <section
        ref={(a) => { innerRef(a); }}
        className="tas-table__tool-bar"
      >
        {selectedCount ? (
          <section className="tas-table__tool-bar-content">
            <span className="tas-table__cell-count">
              {` ${labelChosen}`}
              <span className="tas-table__cell-counter">{selectedCount}</span>
            </span>

            <div className="tas-table__tool-bar-tools">{tools}</div>
          </section>
        ) : (
          <section className={this.toolBarLabelClassName}>
            <section className="tas-table__label">
              {mainLabel}
            </section>

            {withSearchBar && (
              <section className="tas-table__search-bar">
                <div
                  className="tas-table__search-icon"
                  role="presentation"
                  onClick={() => this.handleClick()}
                />

                <div className="tas-table__search-input">
                  <TextInput
                    input={{
                      inputRef: (a) => {
                        this.searchInput = a;
                      },
                      onFocus: () => this.setState({ focused: true }),
                      onChange: event => this.handleChangeSearchValue(event),
                      onBlur: () => this.handleBlur(),
                    }}
                  />
                </div>
              </section>
            )}
          </section>
        )}
      </section>
    );
  }
}
