import { MuiThemeProvider, createMuiTheme } from 'material-ui/styles';
import React from 'react';
import PropTypes from 'prop-types';
import { red } from 'material-ui/colors';

import COLORS from './colors';

const theme = createMuiTheme({
  palette: {
    error: red,
  },
  overrides: {
    MuiButton: {},
    FormHelperText: {
      error: { color: COLORS.ERROR_RED }
    },
    MuiInput: {
      root: {
        '&:after': {
          backgroundColor: `${COLORS.MAIN_BLUE} !important`,
        },
        '&:before': {
          backgroundColor: `${COLORS.MAIN_GRAY} !important`,
          height: `${1}px !important`
        }
      },
      error: {
        '&:after': {
          backgroundColor: `${COLORS.ERROR_RED} !important`,
        },
      }
    },
    MuiTabIndicator: {
      root: {
        backgroundColor: `${COLORS.MAIN_RED} !important`,
        height: 3,
      }
    },
    MuiTabs: {
      root: {
        position: 'relative',
        '&:before': {
          content: '""',
          position: 'absolute',
          bottom: 0,
          left: 0,
          height: 3,
          width: '100%',
          backgroundColor: '#d8d8d8',

        }
      }
    },
    MuiTab: {
      root: {
        flex: 1,
        maxWidth: 'auto',
      }
    }
  },
});

export default class ThemeProvider extends React.PureComponent {
  static displayName = 'ThemeProvider';

  static propTypes = {
    children: PropTypes.element.isRequired,
  };

  render() {
    const { children } = this.props;

    return (
      <MuiThemeProvider theme={theme}>
        {children}
      </MuiThemeProvider>
    );
  }
}
