'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = undefined;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _Paper = require('material-ui/Paper');

var _Paper2 = _interopRequireDefault(_Paper);

var _Menu = require('material-ui/Menu');

var _downshift = require('downshift');

var _downshift2 = _interopRequireDefault(_downshift);

var _TextInput = require('../TextInput');

var _TextInput2 = _interopRequireDefault(_TextInput);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * ## Usage
 *
 * ```javascript
 * import { Field, formValues } from 'redux-form/immutable';
 * import AutoComplete from '@Components/AutoComplete';
 *
 * @formValues('account')
 * export default class {
 *   reloadAccounts(name) {
 *      const apiEndpoint = new URL('http://api.com/countries');
 *      apiEndpoint.searchParams.append('query', name);
 *      fetch(apiEndpoint.toString()).then(response => {
 *        this.setState({
 *          list: this.state.list.merge(response),
 *          name,
 *        });
 *      });
 *   }
 *
 *   getList() {
 *      const { account } = this.props;
 *      const { name } = this.props;
 *      return this.state.list.filter(
 *        option => option.label.like(name) || option.value === account
 *      );
 *   }
 *
 *
 *   render() {
 *     const { list } = this.state;
 *     return (
 *       <Field
 *          name="account"
 *          component={AutoComplete}
 *          label="Select account for payment"
 *          onQueryChange={() => this.reloadAccounts()}
 *          customNormalize={value = value.replace(/[a-zA-Z]/g, '')}
 *       />
 *     );
 *   }
 * }
 * ```
 *
 * ## Other Props
 * All passed props that are not specified in PropTypes will be spreaded to TextInput component
 */
var AutoComplete = function (_React$PureComponent) {
  (0, _inherits3.default)(AutoComplete, _React$PureComponent);

  function AutoComplete() {
    var _ref;

    var _temp, _this, _ret;

    (0, _classCallCheck3.default)(this, AutoComplete);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = (0, _possibleConstructorReturn3.default)(this, (_ref = AutoComplete.__proto__ || (0, _getPrototypeOf2.default)(AutoComplete)).call.apply(_ref, [this].concat(args))), _this), _this.state = {
      menuIsOpen: false
    }, _temp), (0, _possibleConstructorReturn3.default)(_this, _ret);
  }

  (0, _createClass3.default)(AutoComplete, [{
    key: 'getSuggestions',
    value: function getSuggestions(inputValue, list) {
      // eslint-disable-line
      var limit = this.props.limit;

      return list.slice(0, limit);
    }
  }, {
    key: 'findValue',
    value: function findValue(value) {
      return (this.props.list.find(function (item) {
        return item.label === value;
      }) || {}).value;
    }
  }, {
    key: 'renderInput',
    value: function renderInput(inputProps) {
      var _this2 = this;

      // eslint-disable-line
      var InputProps = inputProps.InputProps,
          ref = inputProps.ref,
          other = (0, _objectWithoutProperties3.default)(inputProps, ['InputProps', 'ref']);
      var _props = this.props,
          customNormalize = _props.customNormalize,
          resetInput = _props.resetInput;


      return _react2.default.createElement(_TextInput2.default, (0, _extends3.default)({}, other, {
        inputRef: ref,
        input: (0, _extends3.default)({}, InputProps, {
          value: resetInput ? '' : customNormalize(InputProps.value),
          onBlur: function onBlur(_ref2) {
            var target = _ref2.target;

            _this2.setState({ menuIsOpen: false });
            InputProps.onBlur(_this2.findValue(target.value));
          },
          onClick: function onClick(_ref3) {
            var target = _ref3.target;

            if (!target.disabled) {
              _this2.setState({ menuIsOpen: true });
              InputProps.onFocus(_this2.findValue(target.value));
            }
          }
        })
      }));
    }
  }, {
    key: 'renderSuggestion',
    value: function renderSuggestion(params) {
      // eslint-disable-line
      var suggestion = params.suggestion,
          index = params.index,
          itemProps = params.itemProps,
          highlightedIndex = params.highlightedIndex,
          selectedItem = params.selectedItem;

      var isHighlighted = highlightedIndex === index;
      var isSelected = selectedItem === suggestion.label;

      return _react2.default.createElement(
        _Menu.MenuItem,
        (0, _extends3.default)({}, itemProps, {
          key: suggestion.label,
          selected: isHighlighted,
          component: 'div',
          style: {
            fontWeight: isSelected ? 500 : 400
          }
        }),
        suggestion.label
      );
    }
  }, {
    key: 'inputValueChange',
    value: function inputValueChange(inputValue) {
      var _props2 = this.props,
          list = _props2.list,
          input = _props2.input;

      var matchingItem = list.find(function (item) {
        return item.label === inputValue;
      });
      if (matchingItem && input.value !== matchingItem.value) {
        input.onChange(matchingItem.value);
      } else if (!matchingItem && inputValue && inputValue.length > 0) {
        this.props.onQueryChange(inputValue);
      } else {
        this.props.onQueryChange('');
      }

      this.setState({ menuIsOpen: false });
    }
  }, {
    key: 'render',
    value: function render() {
      var _this3 = this;

      var _props3 = this.props,
          list = _props3.list,
          meta = _props3.meta,
          _props3$input = _props3.input,
          value = _props3$input.value,
          onChange = _props3$input.onChange,
          otherFieldInputProps = (0, _objectWithoutProperties3.default)(_props3$input, ['value', 'onChange']),
          otherProps = (0, _objectWithoutProperties3.default)(_props3, ['list', 'meta', 'input']);
      var menuIsOpen = this.state.menuIsOpen;

      var selectedOption = list.find(function (item) {
        return item.value === value;
      });

      return _react2.default.createElement(
        _downshift2.default,
        {
          defaultInputValue: selectedOption ? selectedOption.label : value,
          onInputValueChange: function onInputValueChange(inputValue) {
            return _this3.inputValueChange(inputValue);
          }
        },
        function (_ref4) {
          var getInputProps = _ref4.getInputProps,
              getItemProps = _ref4.getItemProps,
              isOpen = _ref4.isOpen,
              inputValue = _ref4.inputValue,
              selectedItem = _ref4.selectedItem,
              highlightedIndex = _ref4.highlightedIndex;
          return _react2.default.createElement(
            'div',
            null,
            _this3.renderInput((0, _extends3.default)({
              fullWidth: true,
              InputProps: getInputProps((0, _extends3.default)({}, otherFieldInputProps)),
              meta: meta
            }, otherProps)),
            isOpen || menuIsOpen ? _react2.default.createElement(
              _Paper2.default,
              { square: true },
              _this3.getSuggestions(inputValue, list).map(function (suggestion, index) {
                return _this3.renderSuggestion({
                  suggestion: suggestion,
                  index: index,
                  itemProps: getItemProps({ item: suggestion.label }),
                  highlightedIndex: highlightedIndex,
                  selectedItem: selectedItem
                });
              })
            ) : null
          );
        }
      );
    }
  }]);
  return AutoComplete;
}(_react2.default.PureComponent);

AutoComplete.displayName = 'AutoComplete';
AutoComplete.propTypes = {
  /**
   * List of suggestion options, if field is initialized with predefined value,
   * options with
   */
  list: _propTypes2.default.arrayOf(_propTypes2.default.shape({
    value: _propTypes2.default.string,
    label: _propTypes2.default.string
  })),
  /** Provided by redux-form */
  input: _propTypes2.default.object,
  /** Provided by redux-form */
  meta: _propTypes2.default.object,
  /**
   * Callback function fired when users changes search query
   *
   * Signature:
   * ```
   * function(string: inputValue) => void
   * ```
   */
  onQueryChange: _propTypes2.default.func,
  limit: _propTypes2.default.number,
  customNormalize: _propTypes2.default.func
};
AutoComplete.defaultProps = {
  list: [],
  input: {},
  meta: {},
  onQueryChange: function onQueryChange() {},
  limit: 5,
  customNormalize: function customNormalize(value) {
    return value;
  }
};
exports.default = AutoComplete;