'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.cityFormatter = exports.default = undefined;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

exports.getAddress = getAddress;
exports.getFormattedAddress = getFormattedAddress;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactGoogleMapsLoader = require('react-google-maps-loader');

var _reactGoogleMapsLoader2 = _interopRequireDefault(_reactGoogleMapsLoader);

var _reactGooglePlacesSuggest = require('react-google-places-suggest');

var _reactGooglePlacesSuggest2 = _interopRequireDefault(_reactGooglePlacesSuggest);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var DEBOUNCE_TIMEOUT = 250;

/**
 * Wrapper for react-google-maps-loader and react-google-places-suggest libraries
 *
 * ## Usage
 * ```javascript
 * import GooglePlaceSuggestion, { getAddress } from '@Components/GooglePlaceSuggestion'
 *
 * @formValues('search')
 * @connect(, dispatch => ({
 *  doSelectSuggestion(suggestion) {
 *    dispatch(change('FORM_NAME', 'search', suggestion));
 *  }
 * }))
 * class SuggestionInput extends React.PureComponent {
 *  render() {
 *    const { search, doSelectSuggestion } = this.props;
 *    return (
 *      <GooglePlaceSuggestion
 *        autocompletionRequest={{
 *          componentRestrictions: { country: 'ua' }, // Restrictions for suggestions
 *          types: ['(cities)'], // Suggestions types
 *        }}
 *        search={search}
 *        onSelectSuggest={doSelectSuggestion}
 *        suggestionFormatter={getAddress}
 *      >
 *        <Field
 *          name="search"
 *          component={TextInput}
 *        />
 *      </GooglePlaceSuggestion>
 *    );
 *  }
 * }
 * ```
 *
 */

var GooglePlaceSuggestion = function (_React$Component) {
  (0, _inherits3.default)(GooglePlaceSuggestion, _React$Component);

  function GooglePlaceSuggestion() {
    var _ref;

    var _temp, _this, _ret;

    (0, _classCallCheck3.default)(this, GooglePlaceSuggestion);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = (0, _possibleConstructorReturn3.default)(this, (_ref = GooglePlaceSuggestion.__proto__ || (0, _getPrototypeOf2.default)(GooglePlaceSuggestion)).call.apply(_ref, [this].concat(args))), _this), _this.state = {
      search: '',
      selectedSuggestion: null
    }, _this.timeout = null, _temp), (0, _possibleConstructorReturn3.default)(_this, _ret);
  }

  (0, _createClass3.default)(GooglePlaceSuggestion, [{
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      var _this2 = this;

      if (nextProps.search === this.state.selectedSuggestion) {
        return;
      }
      if (nextProps.search !== this.state.search) {
        clearTimeout(this.timeout);
        this.timeout = setTimeout(function () {
          _this2.setState({ search: nextProps.search });
        }, DEBOUNCE_TIMEOUT);
      }
    }
  }, {
    key: 'shouldComponentUpdate',
    value: function shouldComponentUpdate() {
      var _this3 = this;

      setTimeout(function () {
        _this3.forceUpdate();
      }, 500);

      return false;
    }
  }, {
    key: 'onSelect',
    value: function onSelect(suggest) {
      var formattedSuggestion = this.props.suggestionFormatter(suggest);
      // Blocks state search update until the search will not be changed
      this.setState({ search: '', selectedSuggestion: formattedSuggestion });
      this.props.onSelectSuggest(formattedSuggestion);
    }
  }, {
    key: 'render',
    value: function render() {
      var _this4 = this;

      var _props = this.props,
          children = _props.children,
          autocompletionRequest = _props.autocompletionRequest,
          textNoResults = _props.textNoResults,
          onSelectSuggest = _props.onSelectSuggest,
          search = _props.search,
          googleMapsKey = _props.googleMapsKey,
          otherProps = (0, _objectWithoutProperties3.default)(_props, ['children', 'autocompletionRequest', 'textNoResults', 'onSelectSuggest', 'search', 'googleMapsKey']);

      return _react2.default.createElement(
        'div',
        {
          onKeyDown: function onKeyDown(e) {
            if (e.keyCode === 13) {
              e.preventDefault();
            }
          }
        },
        _react2.default.createElement(_reactGoogleMapsLoader2.default, {
          params: {
            key: googleMapsKey,
            libraries: 'places,geocode',
            language: 'uk-UA'
          },
          render: function render(googleMaps) {
            return googleMaps && _react2.default.createElement(
              _reactGooglePlacesSuggest2.default,
              (0, _extends3.default)({
                autocompletionRequest: (0, _extends3.default)({}, autocompletionRequest, {
                  input: _this4.state.search
                }),
                googleMaps: googleMaps,
                onSelectSuggest: function onSelectSuggest(suggest) {
                  return _this4.onSelect(suggest);
                },
                textNoResults: textNoResults
              }, otherProps),
              children
            );
          }
        })
      );
    }
  }]);
  return GooglePlaceSuggestion;
}(_react2.default.Component);

GooglePlaceSuggestion.displayName = 'GooglePlaceSuggestion';
GooglePlaceSuggestion.propTypes = {
  /**
   * Input element
   */
  children: _propTypes2.default.node.isRequired,
  /**
   * Triggers when users selects one of suggestion, argument is google place object
   * processed with suggestionFormatter function
   */
  onSelectSuggest: _propTypes2.default.func.isRequired,
  /**
   * Google Maps Api autocompletion request,
   * {
   *  componentRestrictions: { country: 'ua' }, // Restrictions for suggestions
   *  types: ['(cities)'], // Suggestions types
   *  input: 'Qwerty' // Search query string
   * }
   * Left property input empty
   */
  autocompletionRequest: _propTypes2.default.object.isRequired,
  /** No places found text */
  textNoResults: _propTypes2.default.string,
  search: _propTypes2.default.string.isRequired,
  /** Transforms google place objects to needed format */
  suggestionFormatter: _propTypes2.default.func,
  /** Google Maps API key */
  googleMapsKey: _propTypes2.default.string
};
GooglePlaceSuggestion.defaultProps = {
  suggestionFormatter: getFormattedAddress,
  textNoResults: null,
  /** default Tascombank Google Maps API key */
  googleMapsKey: 'AIzaSyCEMwaR7ipFTdhML9ftKk8Y7dax6HaJYj4'
};
exports.default = GooglePlaceSuggestion;
var cityFormatter = exports.cityFormatter = function cityFormatter(suggestion) {
  return suggestion.formatted_address.replace(/,?\s[\d]{5}$/, '');
};

function getAddress(suggestion) {
  var addressComponents = ['route'];
  return suggestion.address_components && suggestion.address_components.filter(function (component) {
    return addressComponents.includes(component.types[0]);
  }).map(function (component) {
    return component.long_name;
  }).reverse().join();
}

function getFormattedAddress(suggestion) {
  return suggestion.formatted_address;
}