'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = undefined;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactNebo15Mask = require('react-nebo15-mask');

var _reactNebo15Mask2 = _interopRequireDefault(_reactNebo15Mask);

var _TextInput = require('../TextInput');

var _TextInput2 = _interopRequireDefault(_TextInput);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * ## Mask
 * For number use `1`, for string - `w`
 * Example:
 *
 * Phone number mask:
 * ```
 * mask="+38 (011) 111 11 11" // +38 (093) 999 99 99
 * ```
 *
 * Date mask
 * ```
 * mask="11-11-1111"  // 12.12.2012
 * ```
 *
 * Car number
 * ```
 * mask="ww 11 11 ww" // AB 32 23 BA
 * ```
 *
 * ## Usage
 *
 * ```javascript
 * import { Field } from 'redux-form/immutable';
 * import MaskedInput from '@Components/MaskedInput';
 *
 * export default class {
 *   render() {
 *     return (
 *       <Field
 *          name="cardNumber"
 *          component={MaskedInput}
 *          label="Card number"
 *          mask="1111 1111 1111 1111"
 *       />
 *     );
 *   }
 * }
 * ```
 */
var MaskedInput = function (_React$Component) {
  (0, _inherits3.default)(MaskedInput, _React$Component);

  function MaskedInput() {
    (0, _classCallCheck3.default)(this, MaskedInput);
    return (0, _possibleConstructorReturn3.default)(this, (MaskedInput.__proto__ || (0, _getPrototypeOf2.default)(MaskedInput)).apply(this, arguments));
  }

  (0, _createClass3.default)(MaskedInput, [{
    key: 'render',
    value: function render() {
      var _this2 = this;

      var _props = this.props,
          mask = _props.mask,
          withPlaceholder = _props.withPlaceholder,
          showOnFocus = _props.showOnFocus,
          hideOnBlur = _props.hideOnBlur,
          showAlways = _props.showAlways,
          otherProps = (0, _objectWithoutProperties3.default)(_props, ['mask', 'withPlaceholder', 'showOnFocus', 'hideOnBlur', 'showAlways']);


      return _react2.default.createElement(_TextInput2.default, (0, _extends3.default)({}, otherProps, {
        input: (0, _extends3.default)({}, otherProps.input, {
          onBlur: function onBlur(e) {
            return e.stopPropagation();
          },
          onChange: function onChange(e) {
            return e.stopPropagation();
          }
        }),
        inputComponent: _reactNebo15Mask2.default,
        randomName: true,
        inputProps: {
          mask: mask,
          withPlaceholder: withPlaceholder,
          hideOnBlur: hideOnBlur,
          showAlways: showAlways,
          showOnFocus: showOnFocus,
          onChange: function onChange(value) {
            if (value !== _this2.props.input.value) {
              _this2.props.input.onChange(value);
            }
          },
          onBlur: function onBlur(value) {
            return _this2.props.input.onBlur(value);
          }
        }
      }));
    }
  }]);
  return MaskedInput;
}(_react2.default.Component);

MaskedInput.displayName = 'MaskedInput';
MaskedInput.propTypes = (0, _extends3.default)({}, _TextInput2.default.propTypes, {
  label: _propTypes2.default.string,
  disabled: _propTypes2.default.bool,
  prefix: _propTypes2.default.string,
  suffix: _propTypes2.default.string,
  input: _propTypes2.default.object,
  autoFocus: _propTypes2.default.bool,
  theme: _propTypes2.default.oneOf(['default', 'payments-form', 'payments-form-amount']),

  /**
   * For number mask is `1`
   * For string - `w`
   */
  mask: _propTypes2.default.string.isRequired,
  withPlaceholder: _propTypes2.default.string,
  /**
   * Show mask on focus input
   */
  showOnFocus: _propTypes2.default.bool,
  /**
   * Hide mask on blur input
   */
  hideOnBlur: _propTypes2.default.bool,
  /**
   * Always show mask
   */
  showAlways: _propTypes2.default.bool
});
MaskedInput.defaultProps = (0, _extends3.default)({}, _TextInput2.default.defaultProps, {
  withPlaceholder: undefined,
  showOnFocus: true,
  hideOnBlur: true,
  showAlways: false
});
exports.default = MaskedInput;