'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = undefined;

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _dec, _dec2, _class;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _cnDecorator = require('cn-decorator');

var _cnDecorator2 = _interopRequireDefault(_cnDecorator);

var _reactRedux = require('react-redux');

var _Alert = require('../Alert');

var _Alert2 = _interopRequireDefault(_Alert);

var _redux = require('./redux');

require('./index.scss');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * ## Usage
 *
 * ### In store
 *
 * ```javascript
 * import notificationsReducer, { notificationsMiddleware } from '@Components/Notifications/redux';
 *
 * const store = createStore(
 *   combineReducers({ notifications: notificationsReducer }),
 *   applyMiddleware(notificationsMiddleware)
 * );
 * ```
 *
 * ### In root container:
 *
 * ```javascript
 * import Notifications from '@Components/Notifications';
 *
 * export default class {
 *   render() {
 *     return (
 *       <Notifications />
 *     );
 *   }
 * }
 * ```
 *
 * ### Throw `NotificationError`
 *
 * ```javascript
 * throw new NotificationError({
 *   title: 'Throw error',
 *   message: 'Throw error message'
 * });
 * ```
 *
 * ### Actions:
 *
 * - `showNotification({ type: enum(success, warning, error), title: string, message: string })` - Show new notification
 * - `hideNotification(index = 0): any` - Hide notification by index
 * - `hideAllNotifications(): any` - Hide all notifications
 * - `deleteNotification(index = 0): any` - Delete notification on store
 */
var Notifications = (_dec = (0, _reactRedux.connect)(function (store) {
  return {
    notifications: typeof store.get === 'function' ? store.get('notifications') : store.notifications
  };
}, { hideNotification: _redux.hideNotification, deleteNotification: _redux.deleteNotification }), _dec2 = (0, _cnDecorator2.default)('notifications'), _dec(_class = _dec2(_class = function (_React$PureComponent) {
  (0, _inherits3.default)(Notifications, _React$PureComponent);

  function Notifications() {
    (0, _classCallCheck3.default)(this, Notifications);
    return (0, _possibleConstructorReturn3.default)(this, (Notifications.__proto__ || (0, _getPrototypeOf2.default)(Notifications)).apply(this, arguments));
  }

  (0, _createClass3.default)(Notifications, [{
    key: 'render',
    value: function render(bem) {
      var _this2 = this;

      var _props = this.props,
          notifications = _props.notifications,
          top = _props.top,
          right = _props.right,
          timeout = _props.timeout;


      return _react2.default.createElement(
        'ul',
        { className: bem(), style: { top: top, right: right } },
        notifications.map(function (item, index) {
          return _react2.default.createElement(
            'li',
            { style: { zIndex: -index }, className: bem('item', { open: item.open }), key: item.title },
            _react2.default.createElement(
              _Alert2.default,
              {
                open: item.open,
                type: item.type,
                timeout: timeout,
                onClose: function onClose() {
                  _this2.props.hideNotification(index);
                },
                onExit: function onExit() {
                  _this2.props.deleteNotification(index);
                }
              },
              _react2.default.createElement('div', { dangerouslySetInnerHTML: { __html: item.message } })
            )
          );
        })
      );
    }
  }]);
  return Notifications;
}(_react2.default.PureComponent)) || _class) || _class);
Notifications.displayName = 'Notifications';
Notifications.propTypes = {
  top: _propTypes2.default.number,
  right: _propTypes2.default.number,
  timeout: _propTypes2.default.number
};
Notifications.defaultProps = {
  top: 24,
  right: 24,
  timeout: 5 * 1000
};
exports.default = Notifications;