'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NotificationError = exports.notificationsMiddleware = exports.hideAllNotifications = exports.deleteNotification = exports.hideNotification = exports.showNotification = undefined;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var SHOW_NOTIFICATION = '@notifications/SHOW';
var HIDE_NOTIFICATION = '@notifications/HIDE';
var DELETE_NOTIFICATION = '@notifications/DELETE';
var HIDE_ALL_NOTIFICATIONS = '@notifications/HIDE_ALL';

var store = { dispatch: function dispatch() {}, getState: function getState() {
    return {};
  } };

var showNotification = exports.showNotification = function showNotification(_ref) {
  var type = _ref.type,
      title = _ref.title,
      message = _ref.message,
      _ref$meta = _ref.meta,
      meta = _ref$meta === undefined ? {} : _ref$meta;
  return {
    type: SHOW_NOTIFICATION,
    payload: {
      type: type, title: title, message: message, meta: meta
    }
  };
};

var hideNotification = exports.hideNotification = function hideNotification() {
  var index = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  return {
    type: HIDE_NOTIFICATION,
    payload: {
      index: index
    }
  };
};

var deleteNotification = exports.deleteNotification = function deleteNotification() {
  var index = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  return {
    type: DELETE_NOTIFICATION,
    payload: {
      index: index
    }
  };
};

var hideAllNotifications = exports.hideAllNotifications = function hideAllNotifications() {
  return {
    type: HIDE_ALL_NOTIFICATIONS,
    payload: null
  };
};

var notificationsMiddleware = exports.notificationsMiddleware = function notificationsMiddleware(_ref2) {
  var dispatch = _ref2.dispatch,
      getState = _ref2.getState;

  store.dispatch = dispatch;
  store.getState = getState;

  return function (next) {
    return function (action) {
      return next(action);
    };
  };
};

var NotificationError = exports.NotificationError = function (_Error) {
  (0, _inherits3.default)(NotificationError, _Error);

  function NotificationError(_ref3) {
    var title = _ref3.title,
        message = _ref3.message,
        meta = _ref3.meta;
    (0, _classCallCheck3.default)(this, NotificationError);

    var _this = (0, _possibleConstructorReturn3.default)(this, (NotificationError.__proto__ || (0, _getPrototypeOf2.default)(NotificationError)).call(this, title + ' - ' + message));

    store.dispatch(showNotification({
      type: 'error',
      title: title,
      message: message,
      meta: meta
    }));
    return _this;
  }

  return NotificationError;
}(Error);

exports.default = function () {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  var action = arguments[1];

  switch (action.type) {
    case SHOW_NOTIFICATION:
      return [].concat((0, _toConsumableArray3.default)(state), [(0, _extends3.default)({}, action.payload, { open: true })]);
    case HIDE_NOTIFICATION:
      var newState = [].concat((0, _toConsumableArray3.default)(state));

      newState[action.payload.index] = (0, _extends3.default)({}, state[action.payload.index], {
        open: false
      });

      return newState;
    case DELETE_NOTIFICATION:
      state.splice(action.payload.index, 1);
      return [].concat((0, _toConsumableArray3.default)(state));
    case HIDE_ALL_NOTIFICATIONS:
      return [].concat((0, _toConsumableArray3.default)(state)).map(function (item) {
        return (0, _extends3.default)({}, item, { open: false });
      });
    default:
      return state;
  }
};